// 以下は、javascript.js ファイルの内容です。

// 画像のロード
const playerImage = new Image();
playerImage.src = 'Image/main.png';  // Imageフォルダからの参照に変更

const enemyImage = new Image();
enemyImage.src = 'Image/enemy.png';  // Imageフォルダからの参照に変更

// 爆発の画像配列をロード
const explosionImages = [];
for (let i = 0; i < 12; i++) {
  const explosionFrame = new Image();
  explosionFrame.src = `ex/${String(i).padStart(3, '0')}.png`;
  explosionImages.push(explosionFrame);
}

// JavaScriptファイルの例
// 画像がロードされたら初期化関数を呼び出す
playerImage.onload = function() {
  initializeGame();
};

enemyImage.onload = function() {
  // エネミーイメージに関する初期化が必要な場合
};

// ゲームの初期化
function initializeGame() {
  // プレイヤーと敵の初期化
  initializePlayer();
  initializeEnemies();
  // ゲームループの開始
gameLoop();
}

// プレイヤーの初期化
function initializePlayer() {
player = {
x: canvas.width / 2,
y: canvas.height - 60,
width: 50, // プレイヤーの画像サイズに応じて調整
height: 50, // プレイヤーの画像サイズに応じて調整
speed: 5,
dx: 0,
dy: 0
};
}

// 敵の初期化
function initializeEnemies() {
// ここに敵を初期化するコード
}

// ゲームループ
function gameLoop() {
ctx.clearRect(0, 0, canvas.width, canvas.height); // 画面をクリア
drawPlayer(); // プレイヤーを描画
drawEnemies(); // 敵を描画
// その他のゲームロジック

if (!gameOver) {
requestAnimationFrame(gameLoop);
}
}

// プレイヤーの描画
function drawPlayer() {
if (playerImage.complete) { // 画像がロードされているか確認
ctx.drawImage(playerImage, player.x, player.y, player.width, player.height);
}
}

// 敵の描画
function drawEnemies() {
enemies.forEach(enemy => {
if (enemyImage.complete) { // 画像がロードされているか確認
ctx.drawImage(enemyImage, enemy.x, enemy.y, enemy.width, enemy.height);
}
});
}

// その他の関数定義...

// ゲームのリセット
function resetGame() {
score = 0;
gameStartTime = Date.now();
gameOver = false;
gameRunning = true;
enemies = []; // 敵の配列をリセット
bullets = []; // 弾の配列をリセット
explosions = []; // 爆発の配列をリセット
initializePlayer(); // プレイヤーを再初期化
initializeEnemies(); // 敵を再初期化
gameLoop(); // ゲームループを再開
}

// ゲームの初期化と開始
initializeGame();



// ... その他の変数と関数 ...

// ゲームループを更新
function gameLoop() {
  // ... その他のゲームループコード ...

  // スコアとゲームオーバーのチェックを追加
  if (Date.now() - gameStartTime >= 60000) { // 60秒経過でゲームオーバー
    gameOver = true;
    // ゲームオーバーロジックを追加
    endGame();
  }

  // 10秒ごとに敵のスピードを1.5倍にする
  if (Math.floor((Date.now() - gameStartTime) / 10000) > enemySpeedMultiplier) {
    enemySpeedMultiplier *= 1.5;
  }

  // ゲームが実行中の場合に限りループを続ける
  if (gameRunning) {
    requestAnimationFrame(gameLoop);
  }
}

function endGame() {
  ctx.font = '30px Arial';
  ctx.fillStyle = 'red';
  ctx.fillText('GAME OVER', canvas.width / 2, canvas.height / 2);
  ctx.fillText('Press Enter to restart', canvas.width / 2, canvas.height / 2 + 30);
  gameRunning = false;
}

// ゲームオーバー時にEnterキーでゲームをリスタート
document.addEventListener('keydown', function(event) {
  if (event.key === 'Enter' && gameOver) {
    // ゲームをリセット
    resetGame();
  }
});

function resetGame() {
  // ゲームステートをリセット
  score = 0;
  gameStartTime = Date.now();
  gameOver = false;
  gameRunning = true;
  // ... その他の状態リセット ...
  gameLoop();
}

// 初期化
resetGame();

// ... その他の関数とイベントハンドラー ...
